@@ -1,7 +1,7 @@
 package Regexp::Pattern::Example;
 
-our $DATE = '2016-12-31'; # DATE
-our $VERSION = '0.1.3'; # VERSION
+our $DATE = '2018-03-24'; # DATE
+our $VERSION = '0.2.0'; # VERSION
 
 # BEGIN_BLOCK: def
 
@@ -18,6 +18,7 @@ A longer description.
 
 _
         pat => qr/.../,
+        tags => ['A','B'],
     },
 
     # dynamic (regexp generator)
@@ -45,6 +46,7 @@ _
                 req => 1,
             },
         },
+        tags => ['B','C'],
     },
 );
 
@@ -65,7 +67,7 @@ Regexp::Pattern::Example - An example Regexp::Pattern::* module
 
 =head1 VERSION
 
-This document describes version 0.1.3 of Regexp::Pattern::Example (from Perl distribution Regexp-Pattern), released on 2016-12-31.
+This document describes version 0.2.0 of Regexp::Pattern::Example (from Perl distribution Regexp-Pattern), released on 2018-03-24.
 
 =head1 SYNOPSIS
 
@@ -134,7 +136,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
